@@ -33,6 +33,7 @@ use crate::{
 use autocxx_parser::TypeConfig;
 use syn::{parse_quote, Fields, Ident, Item, Type, TypePath, UseTree};
 
+use super::type_converter::TypeConversionContext;
 use super::{super::utilities::generate_utilities, type_converter::TypeConverter};
 
 use super::parse_foreign_mod::ParseForeignMod;
@@ -234,15 +235,12 @@ impl<'a> ParseBindgen<'a> {
             }
             Item::Type(mut ity) => {
                 let tyname = QualifiedName::new(ns, ity.ident.clone());
-                let type_conversion_results =
-                    self.results
-                        .type_converter
-                        .convert_type(*ity.ty, ns, false, &HashSet::new());
+                let type_conversion_results = self.results.type_converter.convert_type(
+                    *ity.ty,
+                    ns,
+                    &TypeConversionContext::CxxInnerType,
+                );
                 match type_conversion_results {
-                    Err(ConvertError::OpaqueTypeFound) => {
-                        self.add_opaque_type(tyname);
-                        Ok(())
-                    }
                     Err(err) => Err(ConvertErrorWithContext(
                         err,
                         Some(ErrorContext::Item(ity.ident.clone())),
@@ -296,14 +294,6 @@ impl<'a> ParseBindgen<'a> {
             .any(|id| id == "_unused")
     }
 
-    fn add_opaque_type(&mut self, name: QualifiedName) {
-        self.results.apis.push(UnanalyzedApi {
-            name,
-            deps: HashSet::new(),
-            detail: ApiDetail::OpaqueTypedef,
-        });
-    }
-
     /// Record the Api for a type, e.g. enum or struct.
     /// Code generated includes the bindgen entry itself,
     /// various entries for the cxx::bridge to ensure cxx
